@@ -15,7 +15,7 @@ from os import makedirs, remove
 from os.path import join as path_join, expanduser, abspath, exists, dirname, basename
 from threading import Thread
 
-from astersay.utils import prepare_dialog_name, import_string
+from astersay.utils import prepare_dialog_name, import_string, make_checksum
 
 logger = getLogger(__name__)
 
@@ -25,6 +25,22 @@ DEFAULT_DIALOG = {
     'constants': {
         'manager_contact': 'Менеджер Василий +79008001234',
     },
+    'variables': {
+        # Инициализация переменных на уровне диалога.
+        'caller_name': 'Аноним',
+    },
+    # Бэкэнды распознавания и синтеза можно задавать на уровне диалога,
+    # но синтез ещё и на уровне конкретного блока (скрипта). Если эти
+    # настройки не определены в диалоге или являются пустыми словарями, то
+    # используются настройки уровня приложения.
+    'recognizer': {
+        # 'backend': 'astersay.backends.yandex.YandexRecognizer',
+        # 'params': {}
+    },
+    'synthesizer': {
+        # 'backend': 'astersay.backends.yandex.YandexSynthesizer',
+        # 'params': {}
+    },
     'main_script': [
         # При успехе следующим будет исполнен скрипт '003', иначе '005'.
         {'name': '001', 'success': '002', 'fail': '005'},
@@ -548,17 +564,45 @@ class Settings:
             self.dialog_name = name
         return self.dialog_name
 
-    def get_recognizer(self):
-        if not hasattr(self, '_recognizer'):
-            Recognizer = import_string(self.main['recognizer'])
-            self._recognizer = Recognizer(self)
-        return self._recognizer
+    def get_recognizer(self, backend=None, **params):
+        """
+        Возвращает настроенный объект распознавателя.
+        """
+        if backend:
+            suffix = '_%s' % make_checksum({
+                'backend': backend,
+                'params': params,
+            })
+        else:
+            suffix = ''
+        attr = '_recognizer%s' % suffix
+        if not hasattr(self, attr):
+            if not backend:
+                backend = self.main['recognizer']
+            Recognizer = import_string(backend)
+            setattr(self, attr, Recognizer(self, extra=params))
+        return getattr(self, attr)
 
-    def get_synthesizer(self):
+    def get_synthesizer(self, backend=None, **params):
+        """
+        Возвращает настроенный объект синтезатора. Для уровня диалога в
+        качестве уникальной строки задайте "_<backend>_<hash params>".
+        """
+        logger.info('Backend %s, params %s', backend, params)
+        if backend:
+            suffix = '_%s' % make_checksum({
+                'backend': backend,
+                'params': params,
+            })
+        else:
+            suffix = ''
+        attr = '_synthesizer%s' % suffix
         if not hasattr(self, '_synthesizer'):
-            Synthesizer = import_string(self.main['synthesizer'])
-            self._synthesizer = Synthesizer(self)
-        return self._synthesizer
+            if not backend:
+                backend = self.main['synthesizer']
+            Synthesizer = import_string(backend)
+            setattr(self, attr, Synthesizer(self, extra=params))
+        return getattr(self, attr)
 
     def get_morphology_processor(self):
         module = self.dialog_scheme.get('morphology_processor')
