@@ -166,10 +166,17 @@ class BaseDialog:
         self.amplitude = []
         self.silence_seconds = 0
 
-        self.synthesizer = settings.get_synthesizer()
-        self.recognizer = settings.get_recognizer()
+        # Глобальная конфигурация бекендов уровня диалога. В атрибутах
+        # `synthesizer` и `recognizer` хранятся экземпляры классов используемые
+        # в текущий момент, поэтому нельзя на них ссылаться как на постоянные.
+        scheme = settings.dialog_scheme
+        self.synthesizer = self.main_synthesizer = settings.get_synthesizer(
+            **scheme.get('synthesizer', {}))
+        self.recognizer = settings.get_recognizer(
+            **scheme.get('recognizer', {}))
         if hasattr(self.recognizer, 'token_manager'):
             self.recognizer.token_manager.update_token()
+
         self.morphology_processor = settings.get_morphology_processor()
         self.text_buffers = OrderedDict()
         # Словарь для экспортируемых после завершения в Asterisk переменных.
@@ -602,6 +609,9 @@ class BaseDialog:
             plugin_data = json.load(open(tempfile_name))
             variables.update(plugin_data['variables'])
             # Предварительный фоновый синтез текстов.
+            # Заметьте, что такой синтез будет выполняться с тем синтезатором,
+            # который используется для блока, в котором запускается вызов
+            # плагина.
             synthesize = plugin_data.get('synthesize', [])
             if synthesize and isinstance(synthesize, list):
                 def make_voices():
@@ -629,8 +639,8 @@ class BaseDialog:
             )
             for _name, _logger in loggers:
                 if _name in ("debug", "info", "warnings", "errors") and _name in plugin_data:
-                    # TODO: сменить на warning в версии 0.20:
-                    log_info(_(
+                    # TODO: удалить в версии 0.30:
+                    log_warning(_(
                         '< PLUGIN Параметр %r скоро устареет, используйте один из: '
                         '"log_debug", "log_info", "log_warning" или "log_error"'
                     ), _name)
@@ -641,10 +651,13 @@ class BaseDialog:
         return res, plugin_data
 
     def main_script(self):
-        scheme = self.settings.dialog_scheme
+        settings = self.settings
+        scheme = settings.dialog_scheme
         constants = scheme.get('constants', {})
+        default_variables = scheme.get('variables', {})
         self.export = variables = OrderedDict()
         self.chain = chain = []
+        variables.update(default_variables)
         variables.update(constants)
         # Словарь скриптов.
         scripts = scheme.get('scripts', {})
@@ -669,6 +682,14 @@ class BaseDialog:
                 debug_args.append(process['group'].upper())
             log_debug(debug_msg, *debug_args)
 
+            # Конфигурация `synthesizer` уровня блока (скрипта).
+            # Объект `recognizer` нельзя переопределить на этом уровне.
+            synth_conf = script.get('synthesizer', {})
+            if synth_conf:
+                self.synthesizer = settings.get_synthesizer(**synth_conf)
+            else:
+                self.synthesizer = self.main_synthesizer
+
             self.partials_begin = 0
             if 'partials_begin' in script:
                 try:
@@ -837,8 +858,7 @@ class BaseDialog:
 
         maxtime = float(script.get('maxtime', 600))
         minlength = int(script.get('minlength', 10))
-        # TODO: убрать в версии 0.20 параметр `silence`.
-        maxsilence = int(script.get('maxsilence', script.get('silence', 10)))
+        maxsilence = int(script.get('maxsilence', 10))
         stopwords = script.get('stopwords', [])
         log_debug(_('Ограничение по времени: %s секунд.'), maxtime)
         log_debug(_('Ограничение по длине: от %s символов.'), minlength)
